Module typst_export

Module typst_export 

Typst-based annotated slide export.

This module composes source PDF pages, ink annotations, whiteboard ink, and Typst text boxes into a new Typst document and exports it to PDF, SVG, or PNG.

Structs

AnnotatedExport
Inputs for annotated export.
ExportArtifact
A rendered export artifact.

Enums

ExportFormat
Output format for annotated exports.
ExportLayers
Content layers to include in the export.
TypstExportError
Errors produced while composing or exporting annotated slides.
WhiteboardExport
Whiteboard export behavior.

Functions

export_annotated
Export annotated slides.
export_annotated_from_bytes
Export annotated slides from an already-open document and source PDF bytes.